Method: Cequel::Record::Schema::ClassMethods#synchronize_schema

Defined in:
lib/cequel/record/schema.rb

#synchronize_schemavoid

This method returns an undefined value.

Read the current schema assigned to this record’s table from Cassandra, and make any necessary modifications (including creating the table for the first time) so that it matches the schema defined in the record definition

Since:

  • 1.0.0



79
80
81
82
# File 'lib/cequel/record/schema.rb', line 79

def synchronize_schema
  Cequel::Schema::TableSynchronizer
    .apply(connection, read_schema, table_schema)
end