Method: Cequel::Record::RecordSet#before

Defined in:
lib/cequel/record/record_set.rb

#before(end_key) ⇒ RecordSet

Restrict records to ones whose value in the first unscoped primary key column are strictly less than the given end_key.

Parameters:

  • end_key

    the exclusive upper bound for the key column

Returns:

  • (RecordSet)

    record set with upper bound applied

See Also:

Since:

  • 1.0.0



377
378
379
# File 'lib/cequel/record/record_set.rb', line 377

def before(end_key)
  scoped(upper_bound: bound(false, false, end_key))
end