Module: Cequel::Record::Timestamps

Extended by:
ActiveSupport::Concern
Defined in:
lib/cequel/record/timestamps.rb

Overview

This module provides created_at and updated_at functionality for records. It does this in two ways:

  • If a record’s primary key is a timeuuid with the :auto option set, the created_at method will return the time extracted from the primary key.

  • Calling the timestamps macro in the class definition will define the updated_at and (if necessary) created_at columns, and set up lifecycle hooks to populate them appropriately.

Examples:

Record class with timestamps

class Blog
  include Cequel::Record
  key :subdomain, :text
  column :name, :text

  timestamps
end

Since:

  • 1.3.0

Defined Under Namespace

Modules: ClassMethods