Method: Cequel::Record::RecordSet#before
- Defined in:
- lib/cequel/record/record_set.rb
#before(end_key) ⇒ RecordSet
Restrict records to ones whose value in the first unscoped primary key column are strictly less than the given end_key.
377 378 379 |
# File 'lib/cequel/record/record_set.rb', line 377 def before(end_key) scoped(upper_bound: bound(false, false, end_key)) end |