Module: Cequel::Record::Timestamps
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/cequel/record/timestamps.rb
Overview
This module provides created_at and updated_at functionality for records. It does this in two ways:
-
If a record’s primary key is a
timeuuidwith the:autooption set, thecreated_atmethod will return the time extracted from the primary key. -
Calling the
timestampsmacro in the class definition will define theupdated_atand (if necessary)created_atcolumns, and set up lifecycle hooks to populate them appropriately.
Defined Under Namespace
Modules: ClassMethods